Citing SeaFlux
==============

If you would like to cite or reference SeaFlux, please use one or both of the following if appropriate:

**DATA:** Fay, A. R., Gregor, L., Landschützer, P., McKinley, G. A., Gruber, N., Gehlen, M., Iida, Y., Laruelle, G. G., Rödenbeck, C., and Zeng, J.: Harmonization of global surface ocean pCO2 mapped products and their flux calculations; an improved estimate of the ocean carbon sink, Earth Syst. Sci. Data Discuss. [preprint], [https://doi.org/10.5194/essd-2021-16](https://doi.org/10.5194/essd-2021-16), in review, 2021.

**CODE:** Luke Gregor, & Matthew Humphreys. (2021, April 1). lukegre/SeaFlux: Updated continuous integration and docs (Version 2.0.0). Zenodo. [http://doi.org/10.5281/zenodo.4659162](http://doi.org/10.5281/zenodo.4659162)


Code Contributors
-----------------

- [Luke Gregor](https://github.com/luke-gregor) - Environmental Physics, ETH Zuerich: Zurich, Switzerland. (ORCID: [0000-0001-6071-1857](https://orcid.org/0000-0001-6071-1857))
- [Matthew Humphreys](https://github.com/mvdh7) - Royal Netherlands Institute for Sea Research: Texel, The Netherlands. (ORCID: [0000-0002-9371-7128](http://orcid.org/0000-0002-9371-7128))
